@@ -6,7 +6,7 @@
 #'
 #' Attributes are ignored.
 #'
-#' @seealso \code{\link{is_false}} for complement
+#' @seealso [is_false()] for complement
 #' @inheritParams expect_that
 #' @family expectations
 #' @examples
@@ -29,25 +29,25 @@ NULL
 #' @export
 #' @rdname logical-expectations
 expect_true <- function(object, info = NULL, label = NULL) {
-  lab <- make_label(object, label)
+  act <- quasi_label(enquo(object), label)
 
   expect(
-    identical(as.vector(object), TRUE),
-    sprintf("%s isn't true.", lab),
+    identical(as.vector(act$val), TRUE),
+    sprintf("%s isn't true.", act$lab),
     info = info
   )
-  invisible(object)
+  invisible(act$val)
 }
 
 #' @export
 #' @rdname logical-expectations
 expect_false <- function(object, info = NULL, label = NULL) {
-  lab <- make_label(object, label)
+  act <- quasi_label(enquo(object), label)
 
   expect(
-    identical(as.vector(object), FALSE),
-    sprintf("%s isn't false.", lab),
+    identical(as.vector(act$val), FALSE),
+    sprintf("%s isn't false.", act$lab),
     info = info
   )
-  invisible(object)
+  invisible(act$val)
 }
