@@ -9,7 +9,9 @@ NULL
 #' were, you'll need to run a more informative test reporter.
 #'
 #' @export
-MinimalReporter <- R6::R6Class("MinimalReporter", inherit = Reporter,
+#' @family reporters
+MinimalReporter <- R6::R6Class("MinimalReporter",
+  inherit = Reporter,
   public = list(
     add_result = function(context, test, result) {
       self$cat_tight(single_letter_summary(result))
