@@ -7,7 +7,22 @@ test_that("old school logical works", {
 
 test_that("old school types still work", {
   expect_success(expect_that(1L, is_a("integer")))
-  expect_success(expect_that(NULL, is_null()))
+})
+
+test_that("tidyverse conflicts throw warnings", {
+  expect_warning(
+    expect_that(NULL, is_null()),
+    "deprecated"
+  )
+
+  expect_warning(
+    expect_that("te*st", matches("e*", fixed = TRUE)),
+    "deprecated"
+  )
+  expect_warning(
+    expect_that("test", matches("TEST", ignore.case = TRUE)),
+    "deprecated"
+  )
 })
 
 test_that("old school names still work", {
@@ -25,10 +40,6 @@ test_that("old school equality tests still work", {
   expect_success(expect_that(10, is_equivalent_to(10)))
 })
 
-test_that("old school reference equality test", {
-  expect_success(expect_equal_to_reference(1, "one.rds"))
-})
-
 test_that("old school output tests still work", {
   expect_success(expect_that(stop("!"), throws_error()))
   expect_success(expect_that(warning("!"), gives_warning()))
